@@ -10,7 +10,7 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/rc.d/rc.modules-2.6.38.4.new
+config etc/rc.d/rc.modules-3.4.11.new
 
 # If rc.modules is a real file, back it up:
 if [ -r etc/rc.d/rc.modules -a ! -L etc/rc.d/rc.modules ]; then
@@ -19,12 +19,12 @@ fi
 
 # A good idea whenever kernel modules are added or changed:
 if [ -x sbin/depmod ]; then
-  chroot . /sbin/depmod -a 2.6.38.4 1> /dev/null 2> /dev/null
+  chroot . /sbin/depmod -a 3.4.11 1> /dev/null 2> /dev/null
 fi
 
-( cd lib/modules/2.6.38.4-versatile ; rm -rf source )
-( cd lib/modules/2.6.38.4-versatile ; ln -sf ../../../usr/src/linux-2.6.38.4 source )
-( cd lib/modules/2.6.38.4-versatile ; rm -rf build )
-( cd lib/modules/2.6.38.4-versatile ; ln -sf ../../../usr/src/linux-2.6.38.4 build )
-( cd etc/rc.d ; rm -rf rc.modules-2.6.38.4-versatile )
-( cd etc/rc.d ; ln -sf rc.modules-2.6.38.4 rc.modules-2.6.38.4-versatile )
+( cd etc/rc.d ; rm -rf rc.modules-3.4.11-versatile )
+( cd etc/rc.d ; ln -sf rc.modules-3.4.11 rc.modules-3.4.11-versatile )
+( cd lib/modules/3.4.11-versatile ; rm -rf source )
+( cd lib/modules/3.4.11-versatile ; ln -sf ../../../usr/src/linux-3.4.11 source )
+( cd lib/modules/3.4.11-versatile ; rm -rf build )
+( cd lib/modules/3.4.11-versatile ; ln -sf ../../../usr/src/linux-3.4.11 build )
